@@ -1,6 +1,6 @@
-from core.handler import Handler
-from core.job import JobInfo
-from core.task_scheduler import set_task_list
+from lesscode_test.core.handler import Handler
+from lesscode_test.core.job import JobInfo
+from lesscode_test.core.task_scheduler import set_task_list
 
 
 def patrol_task(yaml_path: str = None, json_path: str = None, data: dict = None):
