@@ -1,11 +1,11 @@
 from typing import List
 
 import gevent
+from gevent import monkey
 from gevent.pool import Pool
 
-from core.task_handle import TaskInfo, Task
-
-from gevent import monkey
+from lesscode_test.core.task_handle import Task
+from lesscode_test.core.task_info import TaskInfo
 
 monkey.patch_all()
 
